@@ -48,12 +48,13 @@ QList<QAction*> EngrampaMenuPlugin::menuActions(Types types, const QString &uri,
     if (types == MenuPluginInterface::DirectoryView || types == MenuPluginInterface::DesktopWindow)
     {
         if (! selectionUris.isEmpty()) {
-            auto info = FileInfo::fromUri(selectionUris.first(), false);
+            auto info = FileInfo::fromUri(selectionUris.first());
             //special type mountable, return
             qDebug()<<"info isVirtual:"<<info->isVirtual()<<info->mimeType();
             if (selectionUris.first().startsWith("computer:///") ||
                 selectionUris.first().startsWith("trash:///") ||
                 selectionUris.first().startsWith("recent:///") ||
+                selectionUris.first().startsWith("filesafe:///") ||
                 info->isVirtual())
                   return actions;
 
