@@ -128,7 +128,8 @@ void ComputerItemDelegate::paintVolumeItem(QPainter *painter, const QStyleOption
         auto textRect = option.rect;
         textRect.adjust(84, 10, -5, -10);
         textRect.translate(0, -option.fontMetrics.ascent());
-        qApp->style()->drawItemText(painter, textRect, Qt::AlignLeft|Qt::AlignVCenter, option.palette, enable, option.text, QPalette::Text);
+        auto elideText = opt.fontMetrics.elidedText(opt.text, Qt::ElideMiddle, textRect.width());
+        qApp->style()->drawItemText(painter, textRect, Qt::AlignLeft|Qt::AlignVCenter, option.palette, enable, elideText, QPalette::Text);
 
         //space
         bool shouldDrawProgress = false;
@@ -136,9 +137,16 @@ void ComputerItemDelegate::paintVolumeItem(QPainter *painter, const QStyleOption
         auto total = item->totalSpace();
         auto used = item->usedSpace();
         if (total > 0) {
-            auto totalFormat = g_format_size(total);
-            auto usedFormat = g_format_size(used);
-            spaceInfo = QString("%1/%2").arg(usedFormat).arg(totalFormat);
+            char *totalFormat = g_format_size_full(total,G_FORMAT_SIZE_IEC_UNITS);
+            char *usedFormat = g_format_size_full(used,G_FORMAT_SIZE_IEC_UNITS);
+
+            QString totalFormatString(totalFormat);
+            QString usedFormatString(usedFormat);
+
+            totalFormatString.replace("iB", "B");
+            usedFormatString.replace("iB", "B");
+
+            spaceInfo = QString("%1/%2").arg(usedFormatString).arg(totalFormatString);
             g_free(totalFormat);
             g_free(usedFormat);
             shouldDrawProgress = true;
