@@ -63,12 +63,24 @@ public:
 
     Qt::ItemFlags flags(const QModelIndex& index) const override;
 
+    bool dropMimeData(const QMimeData *data, Qt::DropAction action, int row, int column, const QModelIndex &parent);
+
     QString tryGetVolumeUriFromMountRoot(const QString &mountRootUri);
+    QString tryGetVolumeRealUriFromUri(const QString &uri);
+    void addRealUri(const QString &realUri);
+    void removeRealUri(const QString &realUri);
+
+    void refresh();
+
+Q_SIGNALS:
+    void updateLocationRequest(const QString &uri);
+    void invalidateRequest();
 
 private:
     AbstractComputerItem *m_parentNode;
 
     QMap<QString, QString> m_volumeTargetMap;
+    QList<QString> m_volumeRealUri;
 };
 
 #endif // COMPUTERMODEL_H
