@@ -28,9 +28,13 @@ static ComputerProxyModel *global_instance = nullptr;
 
 ComputerProxyModel::ComputerProxyModel(QObject *parent) : QSortFilterProxyModel(parent)
 {
+    setDynamicSortFilter(true);
     auto computerModel = new ComputerModel(this);
     setSourceModel(computerModel);
     m_model = computerModel;
+
+    connect(m_model, &ComputerModel::updateLocationRequest, this, &ComputerProxyModel::updateLocationRequest);
+    connect(m_model, &ComputerModel::invalidateRequest, this, &ComputerProxyModel::invalidateFilter);
 }
 
 ComputerProxyModel *ComputerProxyModel::globalInstance()
@@ -52,11 +56,18 @@ QString ComputerProxyModel::tryGetVolumeUriFromMountTarget(const QString &mountT
     return m_model->tryGetVolumeUriFromMountRoot(mountTargetUri);
 }
 
+QString ComputerProxyModel::tryGetVolumeRealUriFromUri(const QString &uri)
+{
+    return m_model->tryGetVolumeRealUriFromUri(uri);
+}
+
+void ComputerProxyModel::refresh()
+{
+    m_model->refresh();
+}
+
 bool ComputerProxyModel::filterAcceptsRow(int source_row, const QModelIndex &source_parent) const
 {
     auto item = static_cast<AbstractComputerItem *>(m_model->index(source_row, 0, source_parent).internalPointer());
-    if (item->itemType() == AbstractComputerItem::RemoteVolume) {
-        return !item->isHidden();
-    }
-    return true;
+    return !item->isHidden();
 }
