@@ -39,6 +39,11 @@ public:
     AbstractComputerItem *itemFromIndex(const QModelIndex &proxyIndex);
 
     QString tryGetVolumeUriFromMountTarget(const QString &mountTargetUri);
+    QString tryGetVolumeRealUriFromUri(const QString &uri);
+    void refresh();
+
+Q_SIGNALS:
+    void updateLocationRequest(const QString &uri);
 
 protected:
     bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
