@@ -34,8 +34,9 @@ ComputerRemoteVolumeItem::ComputerRemoteVolumeItem(const QString &uri, ComputerM
     updateInfo();
 
     m_model->m_volumeTargetMap.insert(Peony::FileUtils::getTargetUri(uri), uri);
+    m_model->addRealUri(uri);
 
-    qDebug()<<"test";
+    qDebug()<<"create remote volume item:"<<uri;
 }
 
 ComputerRemoteVolumeItem::~ComputerRemoteVolumeItem()
@@ -46,6 +47,7 @@ ComputerRemoteVolumeItem::~ComputerRemoteVolumeItem()
     }
 
     m_model->m_volumeTargetMap.remove(m_uri);
+    m_model->removeRealUri(m_uri);
 }
 
 const QString ComputerRemoteVolumeItem::displayName()
@@ -70,11 +72,7 @@ void ComputerRemoteVolumeItem::findChildren()
                                     m_cancellable, GAsyncReadyCallback(enumerate_async_callback), this);
     g_object_unref(file);
 
-    m_watcher = new Peony::FileWatcher("computer:///", this);
-    connect(m_watcher, &Peony::FileWatcher::fileCreated, this, &ComputerRemoteVolumeItem::onFileAdded);
-    connect(m_watcher, &Peony::FileWatcher::fileDeleted, this, &ComputerRemoteVolumeItem::onFileRemoved);
-    connect(m_watcher, &Peony::FileWatcher::fileChanged, this, &ComputerRemoteVolumeItem::onFileChanged);
-    m_watcher->startMonitor();
+
 }
 
 void ComputerRemoteVolumeItem::updateInfo()
@@ -107,7 +105,18 @@ bool ComputerRemoteVolumeItem::isHidden()
 
 void ComputerRemoteVolumeItem::onFileAdded(const QString &uri)
 {
+    //not include udisk、mobile-disk、local-partition etc.
+    QString targetUri;
+    targetUri = Peony::FileUtils::getTargetUri(uri);
+    m_model->m_volumeTargetMap.insert(uri, targetUri);
+
+    m_model->addRealUri(uri);
+
+    if(!targetUri.isEmpty() && targetUri.contains("file:///"))
+        return;
+
     for (auto item : m_children) {
+        //qDebug() << "ComputerRemoteVolumeItem onFileAdded uri:"<<uri<<item->uri();
         if (item->uri() == uri)
             return;
     }
@@ -122,6 +131,7 @@ void ComputerRemoteVolumeItem::onFileRemoved(const QString &uri)
 {
     int row = -1;
     for (auto item : m_children) {
+        //qDebug() << "ComputerRemoteVolumeItem onFileRemoved uri:"<<uri<<item->uri();
         if (item->uri() == uri) {
             row = m_children.indexOf(item);
             break;
@@ -181,6 +191,14 @@ void ComputerRemoteVolumeItem::find_children_async_callback(GFileEnumerator *enu
         if (!uri)
             continue;
 
+        //not include udisk、mobile-disk、local-partition etc.
+        QString targetUri;
+        targetUri = Peony::FileUtils::getTargetUri(uri);
+        p_this->m_model->m_volumeTargetMap.insert(uri, targetUri);
+        p_this->m_model->addRealUri(uri);
+        if(!targetUri.isEmpty() && targetUri.contains("file:///"))
+            continue;
+
         p_this->m_model->beginInsertItem(p_this->itemIndex(), p_this->m_children.count());
         auto item = new ComputerRemoteVolumeItem(uri, p_this->m_model, p_this);
         p_this->m_children<<item;
@@ -200,6 +218,12 @@ void ComputerRemoteVolumeItem::find_children_async_callback(GFileEnumerator *enu
     if (err) {
         //QMessageBox::critical(0, 0, err->message);
         g_error_free(err);
+    } else {
+        p_this->m_watcher = new Peony::FileWatcher("computer:///", p_this);
+        connect(p_this->m_watcher, &Peony::FileWatcher::fileCreated, p_this, &ComputerRemoteVolumeItem::onFileAdded);
+        connect(p_this->m_watcher, &Peony::FileWatcher::fileDeleted, p_this, &ComputerRemoteVolumeItem::onFileRemoved);
+        connect(p_this->m_watcher, &Peony::FileWatcher::fileChanged, p_this, &ComputerRemoteVolumeItem::onFileChanged);
+        p_this->m_watcher->startMonitor();
     }
 }
 
