@@ -32,10 +32,18 @@
 #include <QMouseEvent>
 #include <QRubberBand>
 
+#include <QDragEnterEvent>
+#include <QDragMoveEvent>
+#include <QDropEvent>
+#include <QApplication>
+#include <QGSettings/qgsettings.h>
+#include <global-settings.h>
+
 #include <QDebug>
 
 ComputerView::ComputerView(QWidget *parent) : QAbstractItemView(parent)
 {
+    setDragDropMode(QAbstractItemView::DropOnly);
     setItemDelegate(new ComputerItemDelegate(this));
 
     m_model = ComputerProxyModel::globalInstance();
@@ -44,6 +52,8 @@ ComputerView::ComputerView(QWidget *parent) : QAbstractItemView(parent)
 
     m_rubberBand = new QRubberBand(QRubberBand::Shape::Rectangle, this);
 
+    connect(m_model, &ComputerProxyModel::updateLocationRequest, this, &ComputerView::updateLocationRequest);
+
     connect(this, &QAbstractItemView::doubleClicked, this, [=](const QModelIndex &index){
         qDebug()<<index.data()<<"double clicked";
     });
@@ -58,11 +68,38 @@ ComputerView::ComputerView(QWidget *parent) : QAbstractItemView(parent)
         this->viewport()->update();
     });
 
+    if (QGSettings::isSchemaInstalled("org.ukui.style"))
+    {
+        adjustLayout();
+        //font monitor, adjust to font size to fix lauout issue, link to bug#65238
+        QGSettings *fontSetting = new QGSettings(FONT_SETTINGS, QByteArray(), this);
+        connect(fontSetting, &QGSettings::changed, this, [=](const QString &key){
+            qDebug() << "fontSetting changed:" << key;
+            if (key == "systemFontSize") {
+                adjustLayout();
+            }
+        });
+    }
+
     setSelectionMode(QAbstractItemView::ExtendedSelection);
     this->viewport()->setMouseTracking(true);
     this->viewport()->installEventFilter(this);
 }
 
+void ComputerView::adjustLayout()
+{
+    QGSettings *fontSetting = new QGSettings(FONT_SETTINGS, QByteArray(), this);
+    int fontSize = fontSetting->get("systemFontSize").toInt();
+    int width = 256 + (fontSize -11) * 64/5;
+    int height = 108 + (fontSize -11) * 36/5;
+    m_volumeItemFixedSize = QSize(width, height);
+
+    int other_width = 108 + (fontSize -11) * 36/5;
+    int other_height = 144 + (fontSize -11) * 48/5;
+    m_remoteItemFixedSize = QSize(other_width, other_height);
+    m_networkItemFixedSize = QSize(other_width, other_height);
+}
+
 bool ComputerView::eventFilter(QObject *object, QEvent *event)
 {
     if (event->type() == QEvent::MouseMove) {
@@ -163,6 +200,16 @@ QString ComputerView::tryGetVolumeUriFromMountTarget(const QString &mountTargetU
     return m_model->tryGetVolumeUriFromMountTarget(mountTargetUri);
 }
 
+QString ComputerView::tryGetVolumeRealUriFromUri(const QString &uri)
+{
+    return m_model->tryGetVolumeRealUriFromUri(uri);
+}
+
+void ComputerView::refresh()
+{
+    m_model->refresh();
+}
+
 void ComputerView::updateEditorGeometries()
 {
     QAbstractItemView::updateEditorGeometries();
@@ -298,6 +345,30 @@ void ComputerView::dataChanged(const QModelIndex &topLeft, const QModelIndex &bo
     this->viewport()->update();
 }
 
+void ComputerView::dragEnterEvent(QDragEnterEvent *event)
+{
+    event->accept();
+}
+
+void ComputerView::dragMoveEvent(QDragMoveEvent *event)
+{
+    event->accept();
+    auto newIndex = indexAt(event->pos());
+    if (newIndex != m_hoverIndex) {
+        m_hoverIndex = newIndex;
+        this->viewport()->update();
+    }
+}
+
+void ComputerView::dropEvent(QDropEvent *event)
+{
+    bool isMoveOp = event->keyboardModifiers() & Qt::ShiftModifier;
+    auto index = indexAt(event->pos());
+    if (index.isValid()) {
+        m_model->dropMimeData(event->mimeData(), isMoveOp? Qt::MoveAction: Qt::CopyAction, index.row(), index.column(), index.parent());
+    }
+}
+
 void ComputerView::layoutVolumeIndexes(const QModelIndex &volumeParentIndex)
 {
     int rowCount = m_model->rowCount(volumeParentIndex);
