@@ -53,6 +53,12 @@ public:
     virtual QRegion visualRegionForSelection(const QItemSelection &selection) const;
 
     QString tryGetVolumeUriFromMountTarget(const QString &mountTargetUri);
+    QString tryGetVolumeRealUriFromUri(const QString &uri);
+
+    void refresh();
+
+Q_SIGNALS:
+    void updateLocationRequest(const QString &uri);
 
 protected:
     void updateEditorGeometries();
@@ -66,10 +72,16 @@ protected:
 
     void dataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight, const QVector<int> &roles = QVector<int>());
 
+    void dragEnterEvent(QDragEnterEvent *event);
+    void dragMoveEvent(QDragMoveEvent *event);
+    void dropEvent(QDropEvent *event);
+
     void layoutVolumeIndexes(const QModelIndex &volumeParentIndex);
     void layoutRemoteIndexes(const QModelIndex &remoteParentIndex);
     void layoutNetworkIndexes(const QModelIndex &networkParentIndex);
 
+    void adjustLayout();
+
 private:
     ComputerProxyModel *m_model;
     QRubberBand *m_rubberBand;
