@@ -25,12 +25,14 @@
 
 #include "abstract-computer-item.h"
 #include <peony-qt/volume-manager.h>
+#include <peony-qt/PeonyFileWatcher>
 
 class ComputerVolumeItem : public AbstractComputerItem
 {
     Q_OBJECT
 public:
     explicit ComputerVolumeItem(GVolume *volume, ComputerModel *model, AbstractComputerItem *parentNode, QObject *parent = nullptr);
+    //explicit ComputerVolumeItem(const QString uri,ComputerModel *model,AbstractComputerItem *parentNode,QObject *parent = nullptr);
     ~ComputerVolumeItem();
 
     void updateInfoAsync();
@@ -58,6 +60,8 @@ public:
     qint64 usedSpace() override {return m_usedSpace;}
     qint64 totalSpace() override {return m_totalSpace;}
 
+    bool isHidden() override;
+
 protected:
     //monitor
     static void volume_changed_callback(GVolume *volume, ComputerVolumeItem *p_this);
@@ -69,24 +73,46 @@ protected:
 
     //mount op
     static void mount_async_callback(GVolume *volume, GAsyncResult *res, ComputerVolumeItem *p_this);
-    static void unmount_async_callback(GMount *mount, GAsyncResult *res, ComputerVolumeItem *p_this);
+    static void unmount_async_callback(GObject *object, GAsyncResult *res, ComputerVolumeItem *p_this);
     static void eject_async_callback(GObject *object, GAsyncResult *res, ComputerVolumeItem *p_this);
+    static void stop_async_callback(GDrive *drive, GAsyncResult *res, ComputerVolumeItem *p_this);
+
+    //watcher
+    //comment gparted process code to fix duplicated volume issue, bug#41623
+//    void collectInfoWhenGpartedOpen(QString uri);
+//    void onFileAdded(const QString &uri);
+//    void onFileRemoved(const QString &uri);
+
+    //gparted
+    //void findChildrenWhenGPartedOpen();
+    //static void enumerate_async_callback(GFile *file, GAsyncResult *res, ComputerVolumeItem *p_this);
+    //static void find_children_async_callback(GFileEnumerator *enumerator, GAsyncResult *res, ComputerVolumeItem *p_this);
+    friend quint64 calcVolumeCapacity(ComputerVolumeItem* pThis);
 
 private Q_SLOTS:
     void onVolumeAdded(const std::shared_ptr<Peony::Volume> volume);
+    void updateBlockIcons();
 
 private:
     QString m_uri;
+    QString m_vfs_uri;
 
     std::shared_ptr<Peony::Volume> m_volume;
     std::shared_ptr<Peony::Mount> m_mount;
     GCancellable *m_cancellable;
+    GCancellable *m_tmpCancellable;
 
     //info
     QString m_displayName;
+    QString m_unixDeviceName;
     QIcon m_icon;
     qint64 m_totalSpace = 0;
     qint64 m_usedSpace = 0;
+
+    Peony::FileWatcher *m_watcher = nullptr;
+    QString m_targetUri;
+
+    bool m_isHidden = false;
 };
 
 #endif // COMPUTERVOLUMEITEM_H
