@@ -4,7 +4,7 @@
 <context>
     <name>ComputerItemDelegate</name>
     <message>
-        <location filename="computer-view/computer-item-delegate.cpp" line="146"/>
+        <location filename="computer-view/computer-item-delegate.cpp" line="155"/>
         <source>You should mount volume first</source>
         <translation>Svazek je třeba nejprve připojit (mount)</translation>
     </message>
@@ -20,20 +20,29 @@
 <context>
     <name>ComputerRemoteVolumeItem</name>
     <message>
-        <location filename="computer-view/computer-remote-volume-item.cpp" line="54"/>
+        <location filename="computer-view/computer-remote-volume-item.cpp" line="56"/>
         <source>Remote</source>
         <translation>Vzdálené</translation>
     </message>
 </context>
+<context>
+    <name>ComputerUserShareItem</name>
+    <message>
+        <location filename="computer-view/computer-user-share-item.cpp" line="16"/>
+        <source>User Share</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>ComputerVolumeItem</name>
     <message>
-        <location filename="computer-view/computer-volume-item.cpp" line="34"/>
+        <location filename="computer-view/computer-volume-item.cpp" line="49"/>
         <source>Volume</source>
         <translation>Svazek</translation>
     </message>
     <message>
-        <location filename="computer-view/computer-volume-item.cpp" line="42"/>
+        <location filename="computer-view/computer-volume-item.cpp" line="58"/>
+        <location filename="computer-view/computer-volume-item.cpp" line="98"/>
         <source>File System</source>
         <translation>Souborový systém</translation>
     </message>
@@ -149,7 +158,7 @@
 <context>
     <name>Peony::ComputerViewContainer</name>
     <message>
-        <location filename="computer-view-container.cpp" line="94"/>
+        <location filename="computer-view-container.cpp" line="111"/>
         <source>Connect a server</source>
         <translation>Připojit k serveru</translation>
     </message>
@@ -158,23 +167,28 @@
         <translation type="vanished">sftp://, atd…</translation>
     </message>
     <message>
-        <location filename="computer-view-container.cpp" line="117"/>
+        <location filename="computer-view-container.cpp" line="127"/>
         <source>Unmount</source>
         <translation>Odpojit</translation>
     </message>
     <message>
-        <location filename="computer-view-container.cpp" line="123"/>
+        <location filename="computer-view-container.cpp" line="133"/>
         <source>Eject</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="computer-view-container.cpp" line="133"/>
-        <location filename="computer-view-container.cpp" line="148"/>
+        <location filename="computer-view-container.cpp" line="157"/>
+        <source>format</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="computer-view-container.cpp" line="167"/>
+        <location filename="computer-view-container.cpp" line="184"/>
         <source>Property</source>
         <translation>Vlastnost</translation>
     </message>
     <message>
-        <location filename="computer-view-container.cpp" line="135"/>
+        <location filename="computer-view-container.cpp" line="169"/>
         <source>You have to mount this volume first</source>
         <translation>Tento svazek je třeba nejprve připojit (mount)</translation>
     </message>
@@ -192,35 +206,39 @@
         <translation>Zobrazit disky, síť a osobní složky.</translation>
     </message>
     <message>
-        <location filename="computer-view/computer-volume-item.cpp" line="338"/>
+        <location filename="computer-view/computer-volume-item.cpp" line="579"/>
         <source>One or more programs prevented the unmount operation.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="computer-view/computer-volume-item.cpp" line="340"/>
+        <location filename="computer-view/computer-volume-item.cpp" line="580"/>
+        <location filename="computer-view/computer-volume-item.cpp" line="584"/>
+        <location filename="computer-view/computer-volume-item.cpp" line="588"/>
         <source>Unmount failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="computer-view/computer-volume-item.cpp" line="341"/>
+        <location filename="computer-view/computer-volume-item.cpp" line="580"/>
+        <location filename="computer-view/computer-volume-item.cpp" line="588"/>
         <source>Error: %1
-Do you want to unmount forcely?</source>
+</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="computer-view/computer-volume-item.cpp" line="360"/>
+        <location filename="computer-view/computer-volume-item.cpp" line="583"/>
+        <source>Unable to unmount it, you may need to close some programs, such as: GParted etc.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="computer-view/computer-volume-item.cpp" line="584"/>
+        <source>%1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="computer-view/computer-volume-item.cpp" line="611"/>
+        <location filename="computer-view/computer-volume-item.cpp" line="626"/>
         <source>Eject failed</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="computer-view/computer-volume-item.cpp" line="361"/>
-        <source>Cancel</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="computer-view/computer-volume-item.cpp" line="362"/>
-        <source>Eject Anyway</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 </TS>
