@@ -33,6 +33,7 @@
 
 #include <QtConcurrent>
 #include <QProcess>
+#include <QMessageBox>
 
 #include <QDebug>
 
@@ -53,11 +54,20 @@ MateTerminalMenuPlugin::MateTerminalMenuPlugin(QObject *parent) : QObject (paren
         while (l) {
             const char *cmd = g_app_info_get_executable(static_cast<GAppInfo*>(l->data));
             QString tmp = cmd;
-            if (tmp.contains("terminal")) {
-                terminal_cmd = tmp;
-                if (tmp == "mate-terminal") {
+            if (tmp.contains("terminal") || tmp.contains("terminator")) {
+                qDebug() << "terminal cmd:" <<tmp;
+                //if has x-terminal-emulator, use it first
+                if (tmp == "terminator") {
+                    terminal_cmd = tmp;
                     break;
                 }
+                else if (terminal_cmd == "mate-terminal"){
+                    //fix endless loop issue
+                    l = l->next;
+                    continue;
+                }
+                else
+                    terminal_cmd = tmp;
             }
             l = l->next;
         }
@@ -82,7 +92,7 @@ void MateTerminalMenuPlugin::openTerminal(){
                    nullptr,
                    &err);
     if (err) {
-        qDebug()<<err->message;
+        qDebug()<<"openTerminal failed:"<<err->message;
         g_error_free(err);
         err = nullptr;
         //try again to open terminal
@@ -101,8 +111,15 @@ void MateTerminalMenuPlugin::tryOpenAgain()
     p.setProgram(terminal_cmd);
     p.setArguments(QStringList()<<"--working-directory"<<absPath);
 //    p.startDetached();
-    p.startDetached(p.program(), p.arguments());
+    bool result = p.startDetached(p.program(), p.arguments());
     p.waitForFinished(-1);
+
+    if (! result)
+    {
+        QMessageBox::critical(nullptr, QObject::tr("Open terminal fail"),
+                              QObject::tr("Open terminal failed, did you removed the default terminal? "
+                                          " If it's true please reinstall it."));
+    }
 }
 
 QList<QAction *> MateTerminalMenuPlugin::menuActions(Types types, const QString &uri, const QStringList &selectionUris)
@@ -126,11 +143,11 @@ QList<QAction *> MateTerminalMenuPlugin::menuActions(Types types, const QString
         if (selectionUris.isEmpty()) {
             m_uri = uri;
             //virtual path not show this option
-            auto info = FileInfo::fromUri(uri, false);
+            auto info = FileInfo::fromUri(uri);
             if (info->isVirtual())
                 return actions;
 
-            QAction *dirAction = new QAction(QIcon::fromTheme("utilities-terminal-symbolic"), tr("Open Directory in T&erminal"), nullptr);
+            QAction *dirAction = new QAction(QIcon::fromTheme("utilities-terminal-symbolic"), tr("Open Directory in Terminal"), nullptr);
             dirAction->connect(dirAction, &QAction::triggered, [=](){
                 openTerminal();
             });
@@ -143,13 +160,13 @@ QList<QAction *> MateTerminalMenuPlugin::menuActions(Types types, const QString
                 return actions;
 
             //virtual path not show this option
-            auto info = FileInfo::fromUri(selectionUris.first(), false);
+            auto info = FileInfo::fromUri(selectionUris.first());
             if (info->isVirtual())
                 return actions;
 
             if (info->isDir()) {
                 m_uri = selectionUris.first();
-                QAction *dirAction = new QAction(QIcon::fromTheme("utilities-terminal-symbolic"), tr("Open Directory in T&erminal"), nullptr);
+                QAction *dirAction = new QAction(QIcon::fromTheme("utilities-terminal-symbolic"), tr("Open Directory in Terminal"), nullptr);
                 dirAction->connect(dirAction, &QAction::triggered, [=](){
                     openTerminal();
                 });
