@@ -4,8 +4,8 @@
 <context>
     <name>Peony::MateTerminalMenuPlugin</name>
     <message>
-        <location filename="../mate-terminal-menu-plugin.cpp" line="116"/>
-        <location filename="../mate-terminal-menu-plugin.cpp" line="126"/>
+        <location filename="../mate-terminal-menu-plugin.cpp" line="150"/>
+        <location filename="../mate-terminal-menu-plugin.cpp" line="169"/>
         <source>Open Directory in Terminal</source>
         <translation>Dizini Terminalde Aç</translation>
     </message>
@@ -20,4 +20,17 @@
         <translation>Terminali menü ile aç</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../mate-terminal-menu-plugin.cpp" line="119"/>
+        <source>Open terminal fail</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mate-terminal-menu-plugin.cpp" line="120"/>
+        <source>Open terminal failed, did you removed the default terminal?  If it&apos;s true please reinstall it.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
